package com.persagy.dmp.rwd.digital.controller;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.ArrayNode;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.basic.utils.JsonNodeUtils;
import com.persagy.dmp.common.constant.CommonConstant;
import com.persagy.dmp.common.constant.ResponseCode;
import com.persagy.dmp.common.context.AppContext;
import com.persagy.dmp.common.exception.BusinessException;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ParamCheckUtil;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.digital.entity.ObjectDigital;
import com.persagy.dmp.mybatis.utils.ConditionUtil;
import com.persagy.dmp.basic.utils.QueryCriteriaHelper;
import com.persagy.dmp.rwd.basic.dto.RequestData;
import com.persagy.dmp.rwd.digital.service.IObjectDigitalService;
import com.persagy.dmp.rwd.digital.service.ProjectBusinessService;
import com.persagy.dmp.rwd.digital.utils.ObjectDigitalCriteriaHelper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * 对象数据 Controller
 * @author Charlie Yu
 * @date 2021-07-08
 */
@RestController
@RequestMapping("/rwd/instance/object")
public class ObjectDigitalController{

    @Autowired
    private IObjectDigitalService service;
    @Autowired
    private ProjectBusinessService projectBusinessService;

    @PostMapping("/query")
    @Deprecated
    public CommonResult<List<ObjectNode>> query(@RequestBody QueryCriteria criteria) {
        if(criteria == null) {
            throw new BusinessException(ResponseCode.A0400.getCode(), ResponseCode.A0400.getDesc());
        }
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE);

        QueryWrapper<ObjectDigital> wrapper = new QueryWrapper<>();
        // 添加所属项目条件
        ConditionUtil.ensureProjectCriteriaDirectly(wrapper);
        // 处理扩展条件
        ObjectDigitalCriteriaHelper.presetDigitalCriteria(criteria);
        // 转换查询条件
        QueryCriteriaHelper.toWrapper(wrapper, criteria, ObjectDigital.class);
        Page page = QueryCriteriaHelper.toPage(criteria);
        if(criteria.isOnlyCount()) {
            Integer total = service.queryCount(wrapper);
            page.setTotal(total);
        } else {
            page = service.queryByCondition(QueryCriteriaHelper.toPage(criteria), wrapper);
        }
        // 处理扩展属性
        List<ObjectNode> records = JsonNodeUtils.toListNode(page.getRecords(), ObjectDigital.EXTRA_COLUMN, criteria.getWithColumns());
        return ResultHelper.multi(records, page.getTotal());
    }

    @PostMapping("/createOne")
    @Deprecated
    public CommonResult<ObjectDigital> create(@RequestBody ObjectNode node){
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);
        ObjectDigital vo = JsonNodeUtils.toEntity(node, ObjectDigital.class, ObjectDigital.EXTRA_COLUMN);
        List<ObjectDigital> voList = CollUtil.newArrayList(vo);
        //创建默认条件
        createDefaultValue(voList);
        //新增对象信息
        service.insert(voList);
        return ResultHelper.single(vo);
    }

    @PostMapping("/create")
    @Deprecated
    public CommonResult<List<ObjectDigital>> createBatch(@RequestBody ArrayNode array){
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);
        //创建对象入参校验
        createInstanceParamVerify(array);

        List<ObjectDigital> voList = JsonNodeUtils.toEntity(array, ObjectDigital.class, ObjectDigital.EXTRA_COLUMN);
        //创建默认条件
        createDefaultValue(voList);
        //批量新增对象信息
        voList = service.insert(voList);
        return ResultHelper.multi(voList);
    }

    @PostMapping("/updateOne")
    @Deprecated
    public CommonResult<ObjectDigital> update(@Valid @RequestBody ObjectNode node){
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);
        ObjectDigital vo = JsonNodeUtils.toEntity(node, ObjectDigital.class, ObjectDigital.EXTRA_COLUMN);
        List<ObjectDigital> voList = CollUtil.newArrayList(vo);
        //创建默认条件
        createDefaultValue(voList);
        //修改对象信息
        service.update(voList);
        return ResultHelper.single(vo);
    }

    @PostMapping("/update")
    @Deprecated
    public CommonResult<List<ObjectDigital>> updateBatch(@Valid @RequestBody ArrayNode array){
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);
        //修改对象入参校验
        updateInstanceParamVerify(array);

        List<ObjectDigital> voList = JsonNodeUtils.toEntity(array, ObjectDigital.class, ObjectDigital.EXTRA_COLUMN);
        //创建默认条件
        createDefaultValue(voList);
        //批量修改对象信息
        voList = service.update(voList);
        return ResultHelper.multi(voList);
    }

    @PostMapping("/deleteOne")
    @Deprecated
    public CommonResult delete(@RequestBody String id){
        if(StringUtils.isEmpty(id)){
            throw new BusinessException(ResponseCode.A0400.getCode(), "id不能为空");
        }
        service.delete(CollUtil.newArrayList(id));
        return ResultHelper.success();
    }

    @PostMapping("/delete")
    @Deprecated
    public CommonResult deleteBatch(@RequestBody List<String> ids){
        if(ids == null || ids.size()<=0){
            throw new BusinessException(ResponseCode.A0400.getCode(), "id不能为空");
        }
        service.delete(ids);
        return ResultHelper.success();
    }
    /***
     * Description: 根据项目id集合批量查询项目信息
     * @param idList : 项目id集合
     * @return : com.persagy.dmp.common.model.response.CommonResult<com.fasterxml.jackson.databind.node.ObjectNode>
     * @author : lijie
     * @date :2021/8/18 15:55
     * Update By lijie 2021/8/18 15:55
     */
    @PostMapping("/batchQueryProjectByIds")
    public CommonResult<List<ObjectDigital>> batchQueryProjectByIds(@RequestBody List<String> idList) {
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE);
        return projectBusinessService.batchQueryProjectByIds(idList);
    }
    /***
     * Description: 根据管理分区id批量查询项目信息
     * @param requestData : 请求参数
     * @return : com.persagy.dmp.common.model.response.CommonResult<com.fasterxml.jackson.databind.node.ObjectNode>
     * @author : lijie
     * @date :2021/8/18 15:55
     * Update By lijie 2021/8/18 15:55
     */
    @PostMapping("/batchQueryProjectByGroupManageZoneIds")
    public CommonResult<List<ObjectDigital>> batchQueryProjectByGroupManageZoneIds(@RequestBody RequestData requestData) {
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE);
        return projectBusinessService.batchQueryProjectByGroupManageZoneIds(requestData.getGroupManageZoneIds());
    }
    /***
     * Description: 根据上级id查询下级关联对象
     * @param requestData : 请求参数
     * @return : com.persagy.dmp.common.model.response.CommonResult<com.fasterxml.jackson.databind.node.ObjectNode>
     * @author : lijie
     * @date :2021/8/18 15:55
     * Update By lijie 2021/8/18 15:55
     */
    @PostMapping("/queryObjectListSuperiorId")
    public CommonResult<List<ObjectDigital>> queryObjectListSuperiorId(@RequestBody RequestData requestData) {
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE);
        return service.queryObjectListSuperiorId(requestData);
    }


    /**
     * 创建默认条件
     * @param voList
     */
    private void createDefaultValue(List<ObjectDigital> voList){
        String groupCode = AppContext.getContext().getGroupCode();
        if(StringUtils.isEmpty(groupCode)){
            //默认集团
            groupCode = CommonConstant.DEFAULT_ID;
        }
        String projectId = AppContext.getContext().getProjectId();
        if(StringUtils.isEmpty(projectId)){
            //默认项目
            projectId = CommonConstant.DEFAULT_ID;
        }
        for (ObjectDigital vo : voList) {
            vo.setGroupCode(groupCode);
            vo.setProjectId(projectId);
        }
    }

    /**
     * 创建实例入参校验
     * @param array
     */
    private void createInstanceParamVerify(ArrayNode array){
        if(array == null || array.size()<=0){
            throw new BusinessException(ResponseCode.A0400.getCode(),ResponseCode.A0400.getCode());
        }
        for (JsonNode jsonNode : array) {
            JsonNode name = jsonNode.get("name");
            if(name == null){
                throw new BusinessException(ResponseCode.A0400.getCode(),"对象名称不能为空");
            }
            JsonNode classCode = jsonNode.get("classCode");
            if(classCode == null){
                throw new BusinessException(ResponseCode.A0400.getCode(),"类型编码不能为空");
            }
        }
    }

    /**
     * 修改实例入参校验
     * @param array
     */
    private void updateInstanceParamVerify(ArrayNode array){
        if(array == null || array.size()<=0){
            throw new BusinessException(ResponseCode.A0400.getCode(),ResponseCode.A0400.getCode());
        }
        for (JsonNode jsonNode : array) {
            JsonNode id = jsonNode.get("id");
            if(id == null){
                throw new BusinessException(ResponseCode.A0400.getCode(),"id不能为空");
            }
        }
    }
}
