package com.persagy.dmp.rwd.digital.service;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.digital.entity.ObjectDigital;
import com.persagy.dmp.rwd.basic.dto.RequestData;

import java.util.List;
import java.util.Map;

/**
 * 对象数据 接口
 * @author Charlie Yu
 * @date 2021-07-08
 */
public interface IObjectDigitalService {

    /**
     * 通过ID查询
     * @param id 主键
     * @return
     */
    ObjectDigital load(String id);

    /**
     * 按条件计数
     * @param queryWrapper 查询条件
     * @return 结果数量
     */
    Integer queryCount(Wrapper<ObjectDigital> queryWrapper);

    /**
     * 按条件查询
     * @param queryWrapper 查询条件
     * @return 列表
     */
    List<ObjectDigital> queryByCondition(Wrapper<ObjectDigital> queryWrapper);

    /**
     * 按条件查询
     * @param page 分页条件
     * @param queryWrapper 查询条件
     * @return 分页结果
     */
    Page queryByCondition(Page page, Wrapper<ObjectDigital> queryWrapper);

    /**
     * 新增
     * @param voList 待新增数据
     * @return 新增后数据
     */
    List<ObjectDigital> insert(List<ObjectDigital> voList);

    /**
     * 修改
     * @param voList 待修改数据
     * @return 修改后数据
     */
    List<ObjectDigital> update(List<ObjectDigital> voList);

    /**
     * 删除
     * @param idList 主键
     */
    void delete(List<String> idList) ;

    /**
     * 查询虚拟信息点
     * @param projectId
     * @param groupCode
     * @param ids
     * @return
     */
    Map<String, List<String>>  queryVirtualCodeMap(String projectId, String groupCode, List<String> ids);
    /***
     * Description: 根据上级id查询下级关联对象
     * @param requestData : 请求参数
     * @return : com.persagy.dmp.common.model.response.CommonResult<java.util.List<com.persagy.dmp.digital.entity.ObjectDigital>>
     * @author : lijie
     * @date :2021/8/24 16:37
     * Update By lijie 2021/8/24 16:37
     */
    CommonResult<List<ObjectDigital>> queryObjectListSuperiorId(RequestData requestData);
}
