package com.persagy.dmp.common.model.entity;

import com.persagy.dmp.common.lang.PsDateTime;

/**
 * 审计信息类接口
 * @author Charlie Yu
 * @version 1.0 2021-03-04
 */
public interface IAuditableEntity extends IBaseEntity {

	/**
	 * 取得创建时间
	 * @return 创建时间
	 */
	PsDateTime getCreationTime();

	/**
	 * 设置创建时间,记录插入时有效
	 * @param creationTime 创建时间
	 */
	void setCreationTime(PsDateTime creationTime);

	/**
	 * 取得创建实体的操作员的登录名
	 * @return 操作员标识
	 */
	String getCreator() ;

	/**
	 * 设置创建实体的操作员标识，记录插入时有效
	 * @param creator 操作员标识
	 */
	void setCreator(String creator);

	/**
	 * 取得最后修改时间.
	 * @return 最后修改时间
	 */
	PsDateTime getModifiedTime();

	/**
	 * 设置最后修改时间.记录更新时有效
	 * @param modifiedTime 最后修改时间
	 */
	void setModifiedTime(PsDateTime modifiedTime);

	/**
	 * 取得最后修改的操作员的登录名.
	 * @return 操作员的登录名.
	 */
	String getModifier();

	/**
	 * 设置最后修改的操作员的登录名,记录更新时有效
	 * @param modifier 操作员的登录名.
	 */
	void setModifier(String modifier);
}
