package com.persagy.dmp.define.client;

import com.persagy.dmp.basic.config.DigitalFeignConfig;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.digital.entity.ObjectDigital;
import com.persagy.dmp.define.entity.ObjectTypeDefine;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 文件管理Client
 * @author Charlie Yu
 * @date 2021-05-15
 */
@FeignClient(name = "dmp-rwd", configuration = DigitalFeignConfig.class,url = "${persagy.bdtp.rwd.service:}")
public interface DigitalDefineClient {

    /**
     * 查询类型定义
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 类型定义
     */
    @PostMapping("/define/type/query")
    CommonResult<List<ObjectTypeDefine>> queryObjectType(
            @RequestParam("groupCode") String groupCode,
            @RequestParam("projectId") String projectId,
            @RequestParam("appId") String appId,
            @RequestParam("userId") String userId,
            @RequestBody QueryCriteria criteria);
    /**
     * 查询类型定义
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 类型定义
     */
    @PostMapping("/rwd/instance/object/batchQueryProjectByGroupManageZoneIds")
    CommonResult<List<ObjectDigital>> batchQueryProjectByGroupManageZoneIds(
            @RequestParam("groupCode") String groupCode,
            @RequestParam("projectId") String projectId,
            @RequestParam("appId") String appId,
            @RequestParam("userId") String userId,
            @RequestBody QueryCriteria criteria);
}
