package com.persagy.dmp.digital.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.handlers.JacksonTypeHandler;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.dmp.common.model.entity.AuditableEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.Set;

/**
 * 对象数据
 * @author Charlie Yu
 * @date 2021-06-25
 */
@Data
@EqualsAndHashCode(callSuper = true)
@TableName(value = "dt_object",autoResultMap = true)
public class ObjectDigital extends AuditableEntity {

    /** 扩展属性列 */
    public static final String EXTRA_COLUMN = "infos";
    /** 扩展属性列 */
    public static final String OBJ_TYPE = "obj_type";

    /** 项目ID */
    private String projectId;
    /** 名称 */
    @NotNull(message = "名称不允许为空")
    @Length(max = 200)
    private String name;
    /** 本地编码 */
    private String localId;
    /** 本地名称 */
    private String localName;
    /** 对象分类 */
    private String objType;
    /** 类型编码 */
    @NotNull(message = "类型编码不允许为空")
    @Length(max = 40)
    private String classCode;
    /** 集团编码 */
    private String groupCode;
    /** 组标识 mysql8中grouping是关键字，必须标识 */
    @TableField(value = "`grouping`")
    private Integer grouping;
    /** 边类型编码 */
    @TableField(typeHandler = JacksonTypeHandler.class)
    private ObjectNode infos;
    /** 虚点清单 */
    @TableField(typeHandler = JacksonTypeHandler.class)
    private List<String> virtualCodes;
    /** 创建应用 */
    private String createApp;
    /** 最后修改应用 */
    private String updateApp;
    /** 符合查询条件的数据总条数 */
    @TableField(exist = false)
    private Integer totalCount;
    /** 来源的对象id集合 */
    @TableField(exist = false)
    private Set<String> objFromIds;
    /** 去向的对象id集合 */
    @TableField(exist = false)
    private Set<String> objToIds;
}
